# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)
from ..._compat import cached_property
from .summarize import (
    SummarizeResource,
    AsyncSummarizeResource,
    SummarizeResourceWithRawResponse,
    AsyncSummarizeResourceWithRawResponse,
    SummarizeResourceWithStreamingResponse,
    AsyncSummarizeResourceWithStreamingResponse,
)
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["ToolsResource", "AsyncToolsResource"]


class ToolsResource(SyncAPIResource):
    @cached_property
    def search(self) -> SearchResource:
        return SearchResource(self._client)

    @cached_property
    def summarize(self) -> SummarizeResource:
        return SummarizeResource(self._client)

    @cached_property
    def with_raw_response(self) -> ToolsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#accessing-raw-response-data-eg-headers
        """
        return ToolsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ToolsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#with_streaming_response
        """
        return ToolsResourceWithStreamingResponse(self)


class AsyncToolsResource(AsyncAPIResource):
    @cached_property
    def search(self) -> AsyncSearchResource:
        return AsyncSearchResource(self._client)

    @cached_property
    def summarize(self) -> AsyncSummarizeResource:
        return AsyncSummarizeResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncToolsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncToolsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncToolsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#with_streaming_response
        """
        return AsyncToolsResourceWithStreamingResponse(self)


class ToolsResourceWithRawResponse:
    def __init__(self, tools: ToolsResource) -> None:
        self._tools = tools

    @cached_property
    def search(self) -> SearchResourceWithRawResponse:
        return SearchResourceWithRawResponse(self._tools.search)

    @cached_property
    def summarize(self) -> SummarizeResourceWithRawResponse:
        return SummarizeResourceWithRawResponse(self._tools.summarize)


class AsyncToolsResourceWithRawResponse:
    def __init__(self, tools: AsyncToolsResource) -> None:
        self._tools = tools

    @cached_property
    def search(self) -> AsyncSearchResourceWithRawResponse:
        return AsyncSearchResourceWithRawResponse(self._tools.search)

    @cached_property
    def summarize(self) -> AsyncSummarizeResourceWithRawResponse:
        return AsyncSummarizeResourceWithRawResponse(self._tools.summarize)


class ToolsResourceWithStreamingResponse:
    def __init__(self, tools: ToolsResource) -> None:
        self._tools = tools

    @cached_property
    def search(self) -> SearchResourceWithStreamingResponse:
        return SearchResourceWithStreamingResponse(self._tools.search)

    @cached_property
    def summarize(self) -> SummarizeResourceWithStreamingResponse:
        return SummarizeResourceWithStreamingResponse(self._tools.summarize)


class AsyncToolsResourceWithStreamingResponse:
    def __init__(self, tools: AsyncToolsResource) -> None:
        self._tools = tools

    @cached_property
    def search(self) -> AsyncSearchResourceWithStreamingResponse:
        return AsyncSearchResourceWithStreamingResponse(self._tools.search)

    @cached_property
    def summarize(self) -> AsyncSummarizeResourceWithStreamingResponse:
        return AsyncSummarizeResourceWithStreamingResponse(self._tools.summarize)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["SearchWebParams"]


class SearchWebParams(TypedDict, total=False):
    query: Required[str]
    """The query to search for"""

    llm_answer: bool
    """Whether to return an LLM-generated answer instead of the search results"""

    top_n: int
    """The number of top results to return"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel

__all__ = ["SearchResponseBundle", "Llm", "Result"]


class Llm(BaseModel):
    answer: str

    answerable_probability: float


class Result(BaseModel):
    content: str

    score: float

    source_url: str


class SearchResponseBundle(BaseModel):
    llm: Optional[Llm] = None

    query: Optional[str] = None

    results: Optional[List[Result]] = None

    total_results: Optional[int] = None
    """Total number of results found"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.tools import search_web_params
from ..._base_client import make_request_options
from ...types.tools.search_response_bundle import SearchResponseBundle

__all__ = ["SearchResource", "AsyncSearchResource"]


class SearchResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#accessing-raw-response-data-eg-headers
        """
        return SearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#with_streaming_response
        """
        return SearchResourceWithStreamingResponse(self)

    def web(
        self,
        *,
        query: str,
        llm_answer: bool | NotGiven = NOT_GIVEN,
        top_n: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SearchResponseBundle:
        """
        Search the web for a given query

        Args:
          query: The query to search for

          llm_answer: Whether to return an LLM-generated answer instead of the search results

          top_n: The number of top results to return

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/tools/search/web",
            body=maybe_transform(
                {
                    "query": query,
                    "llm_answer": llm_answer,
                    "top_n": top_n,
                },
                search_web_params.SearchWebParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SearchResponseBundle,
        )


class AsyncSearchResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncSearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#with_streaming_response
        """
        return AsyncSearchResourceWithStreamingResponse(self)

    async def web(
        self,
        *,
        query: str,
        llm_answer: bool | NotGiven = NOT_GIVEN,
        top_n: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SearchResponseBundle:
        """
        Search the web for a given query

        Args:
          query: The query to search for

          llm_answer: Whether to return an LLM-generated answer instead of the search results

          top_n: The number of top results to return

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/tools/search/web",
            body=await async_maybe_transform(
                {
                    "query": query,
                    "llm_answer": llm_answer,
                    "top_n": top_n,
                },
                search_web_params.SearchWebParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SearchResponseBundle,
        )


class SearchResourceWithRawResponse:
    def __init__(self, search: SearchResource) -> None:
        self._search = search

        self.web = to_raw_response_wrapper(
            search.web,
        )


class AsyncSearchResourceWithRawResponse:
    def __init__(self, search: AsyncSearchResource) -> None:
        self._search = search

        self.web = async_to_raw_response_wrapper(
            search.web,
        )


class SearchResourceWithStreamingResponse:
    def __init__(self, search: SearchResource) -> None:
        self._search = search

        self.web = to_streamed_response_wrapper(
            search.web,
        )


class AsyncSearchResourceWithStreamingResponse:
    def __init__(self, search: AsyncSearchResource) -> None:
        self._search = search

        self.web = async_to_streamed_response_wrapper(
            search.web,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["SummarizeYoutubeParams"]


class SummarizeYoutubeParams(TypedDict, total=False):
    video: Required[str]
    """The ID of the YouTube video to summarize.

    Full URLs and other forms may be accepted, but may not be correctly parsed.
    """

    method: Literal["auto", "simple", "recursive", "multi_modal"]
    """The method to use for summarizing the content.

    Auto decides between 'simple' and 'recursive' by length.
    """

    output_language: Literal["en", "pt", "es", "it", "de", "fr"]
    """The ISO 639-1 langauge code to use for the outputted summary.

    English (en) is recommended.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tools import (
    ToolsResource,
    AsyncToolsResource,
    ToolsResourceWithRawResponse,
    AsyncToolsResourceWithRawResponse,
    ToolsResourceWithStreamingResponse,
    AsyncToolsResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)
from .summarize import (
    SummarizeResource,
    AsyncSummarizeResource,
    SummarizeResourceWithRawResponse,
    AsyncSummarizeResourceWithRawResponse,
    SummarizeResourceWithStreamingResponse,
    AsyncSummarizeResourceWithStreamingResponse,
)

__all__ = [
    "SearchResource",
    "AsyncSearchResource",
    "SearchResourceWithRawResponse",
    "AsyncSearchResourceWithRawResponse",
    "SearchResourceWithStreamingResponse",
    "AsyncSearchResourceWithStreamingResponse",
    "SummarizeResource",
    "AsyncSummarizeResource",
    "SummarizeResourceWithRawResponse",
    "AsyncSummarizeResourceWithRawResponse",
    "SummarizeResourceWithStreamingResponse",
    "AsyncSummarizeResourceWithStreamingResponse",
    "ToolsResource",
    "AsyncToolsResource",
    "ToolsResourceWithRawResponse",
    "AsyncToolsResourceWithRawResponse",
    "ToolsResourceWithStreamingResponse",
    "AsyncToolsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["UserModel", "Workspace", "WorkspaceAPIKey", "WorkspaceAPIKeyWorkspace"]


class WorkspaceAPIKeyWorkspace(BaseModel):
    id: str

    created_at: datetime

    deleted_at: Optional[datetime] = None

    display_name: str


class WorkspaceAPIKey(BaseModel):
    created_at: datetime

    deactivated_at: Optional[datetime] = None

    key: str

    name: str

    workspace: Optional[WorkspaceAPIKeyWorkspace] = None


class Workspace(BaseModel):
    id: str

    api_keys: Optional[List[WorkspaceAPIKey]] = None

    display_name: str

    joined_at: datetime

    role: str


class UserModel(BaseModel):
    id: str

    email: str

    workspaces: Optional[List[Workspace]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.tools import summarize_youtube_params
from ..._base_client import make_request_options
from ...types.tools.summary_item import SummaryItem

__all__ = ["SummarizeResource", "AsyncSummarizeResource"]


class SummarizeResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SummarizeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#accessing-raw-response-data-eg-headers
        """
        return SummarizeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SummarizeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#with_streaming_response
        """
        return SummarizeResourceWithStreamingResponse(self)

    def youtube(
        self,
        *,
        video: str,
        method: Literal["auto", "simple", "recursive", "multi_modal"] | NotGiven = NOT_GIVEN,
        output_language: Literal["en", "pt", "es", "it", "de", "fr"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SummaryItem:
        """
        Summarize The Contents Of The Given Source

        Args:
          video: The ID of the YouTube video to summarize. Full URLs and other forms may be
              accepted, but may not be correctly parsed.

          method: The method to use for summarizing the content. Auto decides between 'simple' and
              'recursive' by length.

          output_language: The ISO 639-1 langauge code to use for the outputted summary. English (en) is
              recommended.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/tools/summarize/youtube",
            body=maybe_transform(
                {
                    "video": video,
                    "method": method,
                    "output_language": output_language,
                },
                summarize_youtube_params.SummarizeYoutubeParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SummaryItem,
        )


class AsyncSummarizeResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSummarizeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncSummarizeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSummarizeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mechanixlabs/python-sdk#with_streaming_response
        """
        return AsyncSummarizeResourceWithStreamingResponse(self)

    async def youtube(
        self,
        *,
        video: str,
        method: Literal["auto", "simple", "recursive", "multi_modal"] | NotGiven = NOT_GIVEN,
        output_language: Literal["en", "pt", "es", "it", "de", "fr"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SummaryItem:
        """
        Summarize The Contents Of The Given Source

        Args:
          video: The ID of the YouTube video to summarize. Full URLs and other forms may be
              accepted, but may not be correctly parsed.

          method: The method to use for summarizing the content. Auto decides between 'simple' and
              'recursive' by length.

          output_language: The ISO 639-1 langauge code to use for the outputted summary. English (en) is
              recommended.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/tools/summarize/youtube",
            body=await async_maybe_transform(
                {
                    "video": video,
                    "method": method,
                    "output_language": output_language,
                },
                summarize_youtube_params.SummarizeYoutubeParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SummaryItem,
        )


class SummarizeResourceWithRawResponse:
    def __init__(self, summarize: SummarizeResource) -> None:
        self._summarize = summarize

        self.youtube = to_raw_response_wrapper(
            summarize.youtube,
        )


class AsyncSummarizeResourceWithRawResponse:
    def __init__(self, summarize: AsyncSummarizeResource) -> None:
        self._summarize = summarize

        self.youtube = async_to_raw_response_wrapper(
            summarize.youtube,
        )


class SummarizeResourceWithStreamingResponse:
    def __init__(self, summarize: SummarizeResource) -> None:
        self._summarize = summarize

        self.youtube = to_streamed_response_wrapper(
            summarize.youtube,
        )


class AsyncSummarizeResourceWithStreamingResponse:
    def __init__(self, summarize: AsyncSummarizeResource) -> None:
        self._summarize = summarize

        self.youtube = async_to_streamed_response_wrapper(
            summarize.youtube,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .summary_item import SummaryItem as SummaryItem
from .search_web_params import SearchWebParams as SearchWebParams
from .search_response_bundle import SearchResponseBundle as SearchResponseBundle
from .summarize_youtube_params import SummarizeYoutubeParams as SummarizeYoutubeParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["SummaryItem"]


class SummaryItem(BaseModel):
    method: Literal["auto", "simple", "recursive", "multi_modal"]

    summary: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .root import (
    RootResource,
    AsyncRootResource,
    RootResourceWithRawResponse,
    AsyncRootResourceWithRawResponse,
    RootResourceWithStreamingResponse,
    AsyncRootResourceWithStreamingResponse,
)
from .tools import (
    ToolsResource,
    AsyncToolsResource,
    ToolsResourceWithRawResponse,
    AsyncToolsResourceWithRawResponse,
    ToolsResourceWithStreamingResponse,
    AsyncToolsResourceWithStreamingResponse,
)
from .users import (
    UsersResource,
    AsyncUsersResource,
    UsersResourceWithRawResponse,
    AsyncUsersResourceWithRawResponse,
    UsersResourceWithStreamingResponse,
    AsyncUsersResourceWithStreamingResponse,
)
from .health import (
    HealthResource,
    AsyncHealthResource,
    HealthResourceWithRawResponse,
    AsyncHealthResourceWithRawResponse,
    HealthResourceWithStreamingResponse,
    AsyncHealthResourceWithStreamingResponse,
)

__all__ = [
    "HealthResource",
    "AsyncHealthResource",
    "HealthResourceWithRawResponse",
    "AsyncHealthResourceWithRawResponse",
    "HealthResourceWithStreamingResponse",
    "AsyncHealthResourceWithStreamingResponse",
    "RootResource",
    "AsyncRootResource",
    "RootResourceWithRawResponse",
    "AsyncRootResourceWithRawResponse",
    "RootResourceWithStreamingResponse",
    "AsyncRootResourceWithStreamingResponse",
    "UsersResource",
    "AsyncUsersResource",
    "UsersResourceWithRawResponse",
    "AsyncUsersResourceWithRawResponse",
    "UsersResourceWithStreamingResponse",
    "AsyncUsersResourceWithStreamingResponse",
    "ToolsResource",
    "AsyncToolsResource",
    "ToolsResourceWithRawResponse",
    "AsyncToolsResourceWithRawResponse",
    "ToolsResourceWithStreamingResponse",
    "AsyncToolsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .user_model import UserModel as UserModel
from .user_view_params import UserViewParams as UserViewParams
